#
# spec file for package python-opencensus-context
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define repo_version 0.11.0
%{?sle15_python_module_pythons}
Name:           python-opencensus-context
Version:        0.1.3
Release:        2.4
Summary:        Python in-process context propogation
License:        Apache-2.0
URL:            https://github.com/census-instrumentation/opencensus-python
Source:         https://github.com/census-instrumentation/opencensus-python/archive/v%{repo_version}.tar.gz#/opencensus-%{repo_version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  %{python_module contextvars if (%python-base >= 3.6 and %python-base < 3.7)}
BuildArch:      noarch
%if 0%{python_version_nodots} == 36
Requires:       python-contextvars
%endif
%python_subpackages

%description
The OpenCensus Runtime Context provides in-process context propagation.
By default, thread local storage is used for Python 2.7, 3.4 and 3.5;
contextvars is used for Python >= 3.6, which provides asyncio support.

%prep
%autosetup -p1 -n opencensus-python-%{repo_version}/context/opencensus-context
# for discovery to work
touch tests/__init__.py

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%{python_expand # delete common files
rm -rf %{buildroot}%{$python_sitelib}/opencensus/__init__.*
rm -rf %{buildroot}%{$python_sitelib}/opencensus/__pycache__
rm -rf %{buildroot}%{$python_sitelib}/opencensus/common/__init__.*
rm -rf %{buildroot}%{$python_sitelib}/opencensus/common/__pycache__
}

%check
%pyunittest -v

%files %{python_files}
%doc CHANGELOG.md README.rst
%license ../../LICENSE
%dir %{python_sitelib}/opencensus
%dir %{python_sitelib}/opencensus/common/
%{python_sitelib}/opencensus/common/runtime_context
%{python_sitelib}/opencensus_context-%{version}*-info

%changelog
* Wed Mar  6 2024 Matej Cepl <mcepl@cepl.eu>
- Clean up the SPEC file
* Tue Mar  5 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Switch package to modern Python Stack on SLE-15
  + Add %%{?sle15_python_module_pythons}
  + Drop %%{?!python_module:%%define python_module() python-%%{**} python3-%%{**}}
* Tue Oct 18 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.1.3
  * Move `version.py` file into `runtime_context` folder (#1143)
* Sat Oct 23 2021 Ben Greiner <code@bnavigator.de>
- Update to 0.1.2
  * Release source distribution
- i.e. they just bumped the version and cleaned up some code syntax
  but the new version is specified as minimum by python-opencensus
  0.8
- Require contextvars for Python 3.6
* Thu Feb 20 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Remove __pycache__ files conflicting with python-opencensus package
* Tue Feb 18 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Remove common files conflicting with python-opencensus package
* Tue Feb 18 2020 Tomáš Chvátal <tchvatal@suse.com>
- Use regular unittest discover instead of setup.py test
* Wed Oct 16 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v0.7.5
